@@ -41,8 +41,8 @@ func printVersion(short bool) {
 
 func printTuple(fmat, section, value string, outputColor color.Paint) {
 	if outputColor != -1 {
-		fmt.Printf(fmat, color.Colorize(section+":", outputColor), color.Colorize(value, color.LightGray))
+		fmt.Fprintf(out, fmat, color.Colorize(section+":", outputColor), color.Colorize(value, color.LightGray))
 		return
 	}
-	fmt.Printf(fmat, section, value)
+	fmt.Fprintf(out, fmat, section, value)
 }
