@@ -66,7 +66,7 @@ func TestK9sValidate(t *testing.T) {
 	mk := NewMockKubeSettings()
 	m.When(mk.CurrentContextName()).ThenReturn("ctx1", nil)
 	m.When(mk.CurrentClusterName()).ThenReturn("c1", nil)
-	m.When(mk.ClusterNames()).ThenReturn([]string{"c1", "c2"}, nil)
+	m.When(mk.ClusterNames()).ThenReturn(map[string]struct{}{"c1": {}, "c2": {}}, nil)
 	m.When(mk.NamespaceNames(namespaces())).ThenReturn([]string{"default"})
 
 	c := config.NewK9s()
@@ -90,7 +90,7 @@ func TestK9sValidateBlank(t *testing.T) {
 	mk := NewMockKubeSettings()
 	m.When(mk.CurrentContextName()).ThenReturn("ctx1", nil)
 	m.When(mk.CurrentClusterName()).ThenReturn("c1", nil)
-	m.When(mk.ClusterNames()).ThenReturn([]string{"c1", "c2"}, nil)
+	m.When(mk.ClusterNames()).ThenReturn(map[string]struct{}{"c1": {}, "c2": {}}, nil)
 	m.When(mk.NamespaceNames(namespaces())).ThenReturn([]string{"default"})
 
 	var c config.K9s
