@@ -26,7 +26,7 @@ type PortForward struct {
 }
 
 // Delete deletes a portforward.
-func (p *PortForward) Delete(_ context.Context, path string, _ *metav1.DeletionPropagation, force bool) error {
+func (p *PortForward) Delete(_ context.Context, path string, _ *metav1.DeletionPropagation, _ bool) error {
 	p.GetFactory().DeleteForwarder(path)
 
 	return nil
