@@ -26,7 +26,7 @@ type ScreenDump struct {
 }
 
 // Delete a ScreenDump.
-func (d *ScreenDump) Delete(path string, _ *metav1.DeletionPropagation, force bool) error {
+func (d *ScreenDump) Delete(_ context.Context, path string, _ *metav1.DeletionPropagation, force bool) error {
 	return os.Remove(path)
 }
 
