@@ -54,7 +54,7 @@ func (s StatefulSet) Render(o interface{}, ns string, r *Row) error {
 		podImageNames(sts.Spec.Template.Spec, true),
 		mapToStr(sts.Labels),
 		asStatus(s.diagnose(sts.Status.Replicas, sts.Status.ReadyReplicas)),
-		toAge(sts.ObjectMeta.CreationTimestamp),
+		toAge(sts.GetCreationTimestamp()),
 	}
 
 	return nil
