@@ -4,7 +4,6 @@ import (
 	"context"
 
 	"github.com/derailed/k9s/internal/client"
-	"github.com/derailed/k9s/internal/render"
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/gdamore/tcell/v2"
 )
@@ -19,7 +18,6 @@ func NewReference(gvr client.GVR) ResourceViewer {
 	r := Reference{
 		ResourceViewer: NewBrowser(gvr),
 	}
-	r.GetTable().SetColorerFn(render.Reference{}.ColorerFunc())
 	r.GetTable().SetBorderFocusColor(tcell.ColorMediumSpringGreen)
 	r.GetTable().SetSelectedStyle(tcell.StyleDefault.Foreground(tcell.ColorWhite).Background(tcell.ColorMediumSpringGreen).Attributes(tcell.AttrNone))
 	r.AddBindKeysFn(r.bindKeys)
