@@ -58,7 +58,7 @@ func TestTableNew(t *testing.T) {
 	}
 	data.Namespace = ""
 
-	v.Update(*data, false)
+	v.Update(data, false)
 	assert.Equal(t, 3, v.GetRowCount())
 }
 
@@ -127,7 +127,7 @@ func (t *mockTableModel) SetLabelFilter(string)              {}
 func (t *mockTableModel) Empty() bool                        { return false }
 func (t *mockTableModel) Count() int                         { return 1 }
 func (t *mockTableModel) HasMetrics() bool                   { return true }
-func (t *mockTableModel) Peek() render.TableData             { return makeTableData() }
+func (t *mockTableModel) Peek() *render.TableData            { return makeTableData() }
 func (t *mockTableModel) Refresh(context.Context) error      { return nil }
 func (t *mockTableModel) ClusterWide() bool                  { return false }
 func (t *mockTableModel) GetNamespace() string               { return "blee" }
@@ -155,7 +155,7 @@ func (t *mockTableModel) ToYAML(ctx context.Context, path string) (string, error
 func (t *mockTableModel) InNamespace(string) bool      { return true }
 func (t *mockTableModel) SetRefreshRate(time.Duration) {}
 
-func makeTableData() render.TableData {
+func makeTableData() *render.TableData {
 	t := render.NewTableData()
 	t.Header = render.Header{
 		render.HeaderColumn{Name: "NAMESPACE"},
@@ -187,7 +187,7 @@ func makeTableData() render.TableData {
 		},
 	}
 
-	return *t
+	return t
 }
 
 func makeContext() context.Context {
